#ifndef LIBKYDATE_H
#define LIBKYDATE_H

#include <time.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef struct _kdk_dateinfo{
    char *date;     // 日期
    char *time;   // 时间
    char *timesec;  //带秒钟数时间
}kdk_dateinfo;

typedef struct _kdk_logn_dateinfo{
    char *date;     // 日期
    char *time;   // 时间
    char *week;
}kdk_logn_dateinfo;


#define CONF_FILE_PATH  "/etc/kydate/dateform.conf"
#define LOCALEDIR "/usr/share/locale/"
#define GETTEXT_PACKAGE "kysdk-date"
#define MAXSIZE 80



/**
 * @brief 获取系统支持的日期格式
 * 
 * @return char** 当前日期支持的日期格式，如"2020/08/01"；返回的是char**，需要要free
 */
extern char** kdk_system_get_dateformat();

/**
 * @brief 设置日期格式
 * 
 * @param date 系统当前支持的日期格式
 * @return int 设置成功返回0，返回其他失败
 */
extern int kdk_system_set_dateformat(char *date);

/**
 * @brief 设置24小时制格式接口
 * 
 * @return int 设置成功返回0，返回其他失败
 */
extern int kdk_system_set_24_timeformat();

/**
 * @brief 设置12小时制格式接口
 * 
 * @return int 设置成功返回0，返回其他失败
 */
extern int kdk_system_set_12_timeformat();

/**
 * @brief 获取当前的日期格式
 * 
 * @return char* 用户的当前日期格式
 */
extern char* kdk_system_get_now_dateformat();

/**
 * @brief 获取当前的时间格式
 * 
 * @return char* 用户的当前时间格式
 */
extern char* kdk_system_get_now_timeformat();

/**
 * @brief 时间格式转换接口
 * 
 * @param struct tm *ptr 用户输入的日期和时间
 * @return kdk_dateinfo* 用户配置文件中的格式的日期，具体信息自取
 */
extern kdk_dateinfo *kdk_system_tran_dateformat(struct tm *ptr);

/**
 * @brief 获取当前时间接口
 * 
 * @return char* 与用户设置时间格式相同的当前时间
 */
extern char* kdk_system_nowtime();

/**
 * @brief 获取当前日期接口
 * 
 * @return char* 与用户设置时间格式相同的当前时间
 */
extern char* kdk_system_nowdate();

/**
 * @brief 获取当前星期接口
 * 
 * @return char* 用户的当前星期
 */
extern char* kdk_system_shortweek();

/**
 * @brief 获取当前星期接口
 * 
 * @return char* 用户的当前星期
 */
extern char* kdk_system_longweek();

/**
 * @brief 获取当前秒钟接口
 * 
 * @return char* 用户的当前的带秒钟数的时间
 */
extern char* kdk_system_second();

/**
 * @brief 获取未登录的时间，星期，月份
 * 
 * @param char * 用户名
 * @return kdk_logn_dateinfo* 登录配置文件中的格式的日期，具体信息自取
 */
extern kdk_logn_dateinfo *kdk_system_logn_dateinfo(char *user);

/**
 * @brief 转换工具箱时间接口
 * 
 * @param char * 工具箱日期
 * @return char* 配置文件中的格式的日期
 */
extern char* kdk_system_gjx_time(char *date);

/**
 * @brief 用于回收字符串列表
 * 
 * @param ptr 字符串列表
 */
extern inline void kdk_date_freeall(char **ptr);

/**
 * @brief 释放由kdk_system_tran_dateformat返回的日期信息结构体
 * 
 * @param date 由kdk_system_tran_dateformat返回的结构体指针
 */
extern void kdk_free_dateinfo(kdk_dateinfo *date);

/**
 * @brief 释放由kdk_free_logn_dateinfo返回的日期信息结构体
 * 
 * @param date 由kdk_free_logn_dateinfo返回的结构体指针
 */
extern void kdk_free_logn_dateinfo(kdk_logn_dateinfo *date);

#ifdef __cplusplus
}
#endif

#endif
/**
  * @}
  */